@@ -76,8 +76,7 @@ class PurchaseRequest(ModelSQL, ModelView):
                 ('id', If(In('company', Eval('context', {})), '=', '!='),
                     Eval('context', {}).get('company', -1)),
             ])
-    origin = fields.Reference('Origin', selection='get_origin', readonly=True,
-            required=True)
+    origin = fields.Reference('Origin', selection='get_origin', readonly=True)
     exception_ignored = fields.Boolean('Ignored Exception')
     state = fields.Selection([
             ('purchased', "Purchased"),
@@ -161,6 +160,9 @@ class PurchaseRequest(ModelSQL, ModelView):
                         [state],
                         where=request.id == request_id))
 
+        # Migration from 4.4: remove required on origin
+        tablehandler.not_null_action('origin', action='remove')
+
     def get_rec_name(self, name):
         product_name = (self.product.name if self.product else
             self.description.splitlines()[0])
@@ -194,7 +196,7 @@ class PurchaseRequest(ModelSQL, ModelView):
 
     @classmethod
     def search_purchase(cls, name, clause):
-        return [('purchase_line.purchase',) + tuple(clause[1:])]
+        return [('purchase_line.' + clause[0],) + tuple(clause[1:])]
 
     @property
     def currency(self):
@@ -252,7 +254,7 @@ class PurchaseRequest(ModelSQL, ModelView):
         models = IrModel.search([
                 ('model', 'in', list(cls._get_origin())),
                 ])
-        return [(m.model, m.name) for m in models]
+        return [(None, '')] + [(m.model, m.name) for m in models]
 
     @classmethod
     def create(cls, vlist):
